powered by
AET05
The AET05 table produces the standard adverse event rate adjusted for patient-years at risk summary considering first occurrence.
aet05_main( adam_db, dataset = "adsaftte", arm_var = "ACTARM", lbl_overall = NULL, ... )aet05_pre(adam_db, dataset = "adsaftte", ...)aet05_post(tlg, prune_0 = FALSE, ...)aet05
aet05_pre(adam_db, dataset = "adsaftte", ...)
aet05_post(tlg, prune_0 = FALSE, ...)
aet05
the main function returns an rtables object.
rtables
the preprocessing function returns a list of data.frame.
list
data.frame
the postprocessing function returns an rtables object or an ElementaryTable (null report).
ElementaryTable
(list of data.frames) object containing the ADaM datasets
data.frames
ADaM
(string) the name of a table in the adam_db object.
string
adam_db
(string) the arm variable used for arm splitting.
(string) label used for overall column, if set to NULL the overall column is omitted
NULL
Further arguments passed to tern::control_incidence_rate().
tern::control_incidence_rate()
(TableTree, Listing or ggplot) object typically produced by a main function.
TableTree
Listing
ggplot
main
(flag) remove 0 count rows
flag
aet05_main(): Main TLG function
aet05_main()
aet05_pre(): Preprocessing
aet05_pre()
aet05_post(): Postprocessing
aet05_post()
Total patient-years at risk is the sum over all patients of the time intervals (in years).
Split columns by arm, typically ACTARM.
ACTARM
Split rows by parameter code.
AVAL is patient-years at risk.
AVAL
N_EVENTS is the number of adverse events observed.
N_EVENTS
The table allows confidence level to be adjusted, default is 95%.
Keep zero count rows by default.
library(dplyr) library(dunlin) proc_data <- log_filter(syn_data, PARAMCD == "AETTE1", "adsaftte") run(aet05, proc_data) run(aet05, proc_data, conf_level = 0.90, conf_type = "exact")
Run the code above in your browser using DataLab