Assert that at least one name is among table names of a dm object
assert_one_tablenames.RdAssert that at least one name is among table names of a dm object
Arguments
- db
(
dm) input to check for the presence or tables.- tab
(
character) the names of the tables to be checked.- null_ok
(
flag) canxbe NULL.- qualifier
(
string) to be returned if the check fails.
Examples
if (FALSE) {
assert_one_tablenames(dm::dm_nycflights13(), c("mpg", "new", "hoho"), qualifier = "first test:")
}