Check that at least one name is among column names
check_one_colnames.RdCheck that at least one name is among column names
Arguments
- df
(
data.frame)- x
(
character) the names of the columns to be checked.- null_ok
(
flag) canxbe NULL.- qualifier
(
string) to be returned if the check fails.
Examples
check_one_colnames(mtcars, c("new", "hoho"))
#> [1] " At least one of: new, hoho is expected to be a column name of mtcars"