chevron packageProvide standard tables, listings, and graphs (TLGs) libraries used in clinical trials. This package implements a structure to reformat the data with 'dunlin', create reporting tables using 'rtables' and 'tern' with standardized input arguments to enable quick generation of standard outputs. In addition, it also provides comprehensive data checks and script generation functionality.
Maintainer: Joe Zhu [email protected] (ORCID)
Authors:
Liming Li [email protected] (ORCID) (Original creator of the package)
Benoit Falquet [email protected] (ORCID) (Original creator of the package)
Xiaoli Duan [email protected]
Other contributors:
Adrian Waddell [email protected] [contributor]
Chenkai Lv [email protected] [contributor]
Pawel Rucki [email protected] [contributor]
Tim Barnett [email protected] [contributor]
Tian Fang [email protected] [contributor]
F. Hoffmann-La Roche AG [copyright holder, funder]