Unite Columns of a Table in a dm object.
dm_unite.RdUnite Columns of a Table in a dm object.
Arguments
- adam_db
(
dm) object containing theADaMdatasets- dataset
(
string) the name of a table in theadam_dbobject.- cols
(
character) the name of the columns to unite.- sep
(
string) the separator for the new column name.- new
(
string) the name of the new column. IfNULLthe concatenation ofcolsseparated bysepis used.