pmap_row.RdRow in Preprocessing Map
pmap_row(tlgfname, filter_fname = NA, mutate_fname = NA, req_data)(character) name of a function which creates a table, listing or graph
(character) name of function which filters the ADaM dm data object
(character) name of function which mutates the ADaM dm data object
(character) vector of data names in the ADaM dm data objects that are required to create the
output
pmap_row("tabc", NA, "identity", c("adsl", "adae"))
#> # A tibble: 1 × 4
#> tlgfname filter_fname mutate_fname req_data
#> <chr> <lgl> <chr> <list>
#> 1 tabc NA identity <chr [2]>