Vital Sign Parameters outside Normal Limits Regardless of Abnormality at Baseline.
Usage
vst02_1_main(
adam_db,
arm_var = "ACTARM",
lbl_overall = NULL,
exclude_base_abn = FALSE,
...
)
vst02_pre(adam_db, ...)
vst02_post(tlg, prune_0 = FALSE, ...)
vst02_1Arguments
- adam_db
(
listofdata.frames) object containing theADaMdatasets- arm_var
(
string) variable used for column splitting- lbl_overall
(
string) label used for overall column, if set toNULLthe overall column is omitted- exclude_base_abn
(
flag) whether baseline abnormality should be excluded.- ...
not used.
- tlg
(
TableTree,Listingorggplot) object typically produced by amainfunction.- prune_0
(
flag) remove 0 count rows
Value
the main function returns an rtables object.
the preprocessing function returns a list of data.frame.
the postprocessing function returns an rtables object or an ElementaryTable (null report).
Details
Only count LOW or HIGH values.
Results of "LOW LOW" are treated as the same as "LOW", and "HIGH HIGH" the same as "HIGH".
Does not include a total column by default.
Does not remove zero-count rows unless overridden with
prune_0 = TRUE.
Examples
run(vst02_1, syn_data)
#> Assessment A: Drug X B: Placebo C: Combination
#> Abnormality (N=134) (N=134) (N=132)
#> ———————————————————————————————————————————————————————————————————————————
#> Diastolic Blood Pressure
#> Low 69/134 (51.5%) 73/134 (54.5%) 67/132 (50.8%)
#> High 76/134 (56.7%) 67/134 (50%) 65/132 (49.2%)
#> Pulse Rate
#> Low 75/134 (56%) 67/134 (50%) 69/132 (52.3%)
#> High 67/134 (50%) 74/134 (55.2%) 53/132 (40.2%)
#> Respiratory Rate
#> Low 70/134 (52.2%) 72/134 (53.7%) 64/132 (48.5%)
#> High 75/134 (56%) 65/134 (48.5%) 71/132 (53.8%)
#> Systolic Blood Pressure
#> Low 71/134 (53%) 69/134 (51.5%) 70/132 (53%)
#> High 78/134 (58.2%) 62/134 (46.3%) 64/132 (48.5%)
#> Temperature
#> Low 66/134 (49.3%) 68/134 (50.7%) 81/132 (61.4%)
#> High 67/134 (50%) 66/134 (49.3%) 69/132 (52.3%)
#> Weight
#> Low 73/134 (54.5%) 71/134 (53%) 76/132 (57.6%)
#> High 69/134 (51.5%) 74/134 (55.2%) 74/132 (56.1%)