chevron_tlg class
chevron_tlg-class.RdThe chevron_tlg class associates a preprocess function, a main tlg function and AdAM tables names and
optionally a postprocess function.
Usage
chevron_tlg(
main = function(adam_db, ...) adam_db,
preprocess = function(adam_db, ...) adam_db,
postprocess = report_null,
adam_datasets = NA_character_
)Arguments
- main
(
function) returning atlg. Typically one of the_mainfunction ofchevron.- preprocess
(
function) returning a pre-processeddmobject amenable totlgcreation. Typically one of the_prefunction ofchevron.- postprocess
(
function) returning a post-processedtlg.- adam_datasets
(
character) representing the name of the table from anAdAMdataset required fortlgcreation.
Slots
main(
function) returning atlg. Typically one of the*_mainfunction fromchevron.preprocess(
function) returning a pre-processeddmobject amenable totlgcreation. Typically one of the*_prefunction fromchevron.postprocess(
function) returning a post-processedtlg.adam_datasets(
character) representing the name of the tables from anAdAMdataset required fortlgcreation.
Note
To ensure the correct execution of the workflow additional validation criteria are:
the first argument of the
mainfunction must beadam_db, the inputdmobject to pre-process.the first argument of the
preprocessfunction must beadam_db, the inputdmobject to createtlgoutput.the first argument of the
postprocessfunction must betlg, the inputTableTreeobject to post-process.
Examples
x <- chevron_tlg(aet01_1_main, aet01_1_pre, adam_datasets = c("adsl", "adae"))